@@ -21,9 +21,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21283 $
+ * $Revision: 23551 $
  * $Author: rjongbloed $
- * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
+ * $Date: 2009-09-29 08:11:15 -0500 (Tue, 29 Sep 2009) $
  */
 
 #ifndef OPAL_CODEC_OPALWAVFILE_H
@@ -37,16 +37,14 @@
 
 #include <ptclib/pwavfile.h>
 
-namespace PWLibStupidLinkerHacks {
-  extern int opalwavfileLoader;
-};
+
+class OpalMediaFormat;
+
 
 /**This class is similar to the PWavFile class found in the PWlib
-   components library. However, it will tranparently convert all data
+   components library. However, it will transparently convert all data
    to/from PCM format, allowing applications to be unconcerned with 
-   the underlying data format. Note that this will only work with
-   sample-based formats that can be converted to/from PCM data, such as
-   uLaw and aLaw
+   the underlying data format.
   */
 
 class OpalWAVFile : public PWAVFile
@@ -90,8 +88,17 @@ class OpalWAVFile : public PWAVFile
       int opts = ModeDefault,     ///<  #OpenOptions enum# for open operation.
       unsigned format = fmt_PCM ///<  Type of WAV File to create
     );
+
+
+    static bool AddMediaFormat(
+      const OpalMediaFormat & mediaFormat
+    );
 };
 
+
+PFACTORY_LOAD(PWAVFileConverterULaw);
+
+
 #endif // OPAL_CODEC_OPALWAVFILE_H
 
 
