@@ -22,9 +22,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21860 $
+ * $Revision: 23862 $
  * $Author: rjongbloed $
- * $Date: 2008-12-22 20:24:22 -0600 (Mon, 22 Dec 2008) $
+ * $Date: 2009-12-09 19:35:47 -0600 (Wed, 09 Dec 2009) $
  */
 
 #ifndef OPAL_CODEC_RFC2833_H
@@ -127,7 +127,7 @@ class OpalRFC2833Proto : public PObject {
 
     PString GetTxCapability() const;
     PString GetRxCapability() const;
-    void SetTxCapability(const PString & codes);
+    void SetTxCapability(const PString & codes, bool merge);
     void SetRxCapability(const PString & codes);
 
     static PINDEX ASCIIToRFC2833(char tone, bool hasNSE);
