@@ -23,9 +23,9 @@
  *
  * Contributor(s): 
  *
- * $Revision: 21293 $
+ * $Revision: 23166 $
  * $Author: rjongbloed $
- * $Date: 2008-10-12 23:24:41 +0000 (Sun, 12 Oct 2008) $
+ * $Date: 2009-07-29 00:04:11 -0500 (Wed, 29 Jul 2009) $
  */
 
 #ifndef OPAL_CODEC_VIDCODEC_H
@@ -147,18 +147,20 @@ class OpalVideoTranscoder : public OpalTranscoder
 
     bool WasLastFrameIFrame() const { return lastFrameWasIFrame; }
     void ForceIFrame()              { forceIFrame = true; }
+
+    PINDEX GetMaxEncoderOutputSize() const { return videoEncoderMaxOutputSize; }
+
   //@}
 
   protected:
     PINDEX inDataSize;
     PINDEX outDataSize;
+    PINDEX videoEncoderMaxOutputSize;
     bool   forceIFrame;
     bool   lastFrameWasIFrame;
 
-#if OPAL_STATISTICS
     DWORD m_totalFrames;
     DWORD m_keyFrames;
-#endif
 };
 
 
@@ -185,6 +187,22 @@ class OpalVideoUpdatePicture : public OpalMediaCommand
     int m_numBlocks;
 };
 
+class OpalVideoUpdatePicture2 : public OpalVideoUpdatePicture
+{
+  PCLASSINFO(OpalVideoUpdatePicture2, OpalVideoUpdatePicture);
+  public:
+    OpalVideoUpdatePicture2(WORD seq, DWORD ts, int firstGOB = -1, int firstMB = -1, int numBlocks = 0)
+      : OpalVideoUpdatePicture(firstGOB, firstMB, numBlocks), m_seq(seq), m_ts(ts)  { }
+
+    virtual PString GetName() const;
+
+    WORD GetSequenceNumber() const { return m_seq; }
+    DWORD GetTimestamp() const     { return m_ts; }
+
+  protected:
+    WORD m_seq;
+    DWORD m_ts;
+};
 
 class OpalTemporalSpatialTradeOff : public OpalMediaCommand
 {
