@@ -18,9 +18,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21346 $
- * $Author: hfriederich $
- * $Date: 2008-10-15 22:21:15 +0000 (Wed, 15 Oct 2008) $
+ * $Revision: 23268 $
+ * $Author: rjongbloed $
+ * $Date: 2009-08-25 03:37:19 -0500 (Tue, 25 Aug 2009) $
  */
 
 #ifndef OPAL_H224_H224HANDLER_H
@@ -229,7 +229,7 @@ public:
                       PBoolean isSource);
   ~OpalH224MediaStream();
   
-  virtual void OnPatchStart();
+  virtual void OnStartMediaPatch();
   virtual PBoolean Close();
   virtual PBoolean ReadPacket(RTP_DataFrame & packet);
   virtual PBoolean WritePacket(RTP_DataFrame & packet);
