@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision$
- * $Author$
- * $Date$
+ * $Revision: 23943 $
+ * $Author: rjongbloed $
+ * $Date: 2010-01-17 19:22:38 -0600 (Sun, 17 Jan 2010) $
  */
 
 #ifndef OPAL_H323_CHANNELS_H
@@ -149,6 +149,16 @@ class H323Channel : public PObject
      */
     virtual unsigned GetSessionID() const;
 
+    /**Set the session number of the channel.
+       During OLC negotations teh master may change the session number being
+       used for the logical channel.
+
+       Returns false if the sesion could not be renumbered.
+      */
+    virtual bool SetSessionID(
+      unsigned sessionID   ///< New session ID
+    );
+
     /**Get the media transport address for the connection.
        This is primarily used to determine if media bypass is possible for the
        call between two connections.
@@ -185,7 +195,7 @@ class H323Channel : public PObject
 
     /**Indicate if has been opened.
      */
-    PBoolean IsOpen() const { return opened && !terminating; }
+    PBoolean IsOpen() const { return opened && m_terminating == 0; }
 
     /**Get the media stream associated with this logical channel.
 
@@ -323,14 +333,16 @@ class H323Channel : public PObject
     virtual void OnMediaCommand(OpalMediaCommand &) { }
 
   protected:
+    virtual void InternalClose();
+
     H323EndPoint         & endpoint;
     H323Connection       & connection;
     H323Capability       * capability;
     H323ChannelNumber      number;
     H323ChannelNumber      reverseChannel;
-    PBoolean                   opened;
-    PBoolean                   paused;
-    PBoolean                   terminating;
+    bool                   opened;
+    bool                   paused;
+    PAtomicInteger         m_terminating;
 
   private:
     unsigned bandwidthUsed;
@@ -394,10 +406,6 @@ class H323UnidirectionalChannel : public H323Channel
      */
     virtual PBoolean Start();
 
-    /**This is called to clean up any threads on connection termination.
-     */
-    virtual void Close();
-
     /**Process a miscellaneous command on the logical channel.
        The default behaviour passes this on to the codec if not NULL.
      */
@@ -417,6 +425,8 @@ class H323UnidirectionalChannel : public H323Channel
     void OnMediaCommand(OpalMediaCommand & command);
 
   protected:
+    virtual void InternalClose();
+
     bool               receiver;
     OpalMediaStreamPtr mediaStream;
 };
@@ -526,14 +536,14 @@ class H323_RealTimeChannel : public H323UnidirectionalChannel
      */
     virtual PBoolean OnSendingPDU(
       H245_H2250LogicalChannelParameters & param  ///<  Open PDU to send.
-    ) const = 0;
+    ) const;
 
     /**This is called when request to create a channel is received from a
        remote machine and is about to be acknowledged.
      */
     virtual void OnSendOpenAck(
       H245_H2250LogicalChannelAckParameters & param ///<  Acknowledgement PDU
-    ) const = 0;
+    ) const;
 
     /**This is called after a request to create a channel occurs from the
        local machine via the H245LogicalChannelDict::Open() function, and
@@ -544,7 +554,7 @@ class H323_RealTimeChannel : public H323UnidirectionalChannel
     virtual PBoolean OnReceivedPDU(
       const H245_H2250LogicalChannelParameters & param, ///<  Acknowledgement PDU
       unsigned & errorCode                              ///<  Error on failure
-    ) = 0;
+    );
 
     /**This is called after a request to create a channel occurs from the
        local machine via the H245LogicalChannelDict::Open() function, and
@@ -554,7 +564,7 @@ class H323_RealTimeChannel : public H323UnidirectionalChannel
      */
     virtual PBoolean OnReceivedAckPDU(
       const H245_H2250LogicalChannelAckParameters & param ///<  Acknowledgement PDU
-    ) = 0;
+    );
 
     /**Set the dynamic payload type used by this channel.
       */
@@ -601,6 +611,16 @@ class H323_RTPChannel : public H323_RealTimeChannel
        RTP_Session member variable.
      */
     virtual unsigned GetSessionID() const;
+
+    /**Set the session number of the channel.
+       During OLC negotations teh master may change the session number being
+       used for the logical channel.
+
+       Returns false if the sesion could not be renumbered.
+      */
+    virtual bool SetSessionID(
+      unsigned sessionID   ///< New session ID
+    );
   //@}
 
   /**@name Overrides from class H323_RealTimeChannel */
@@ -820,10 +840,6 @@ class H323DataChannel : public H323UnidirectionalChannel
 
   /**@name Overrides from class H323Channel */
   //@{
-    /**This is called to clean up any threads on connection termination.
-     */
-    virtual void Close();
-
     /**Indicate the session number of the channel.
        Return session for channel. This returns the session ID of the
        RTP_Session member variable.
@@ -889,6 +905,8 @@ class H323DataChannel : public H323UnidirectionalChannel
   //@}
 
   protected:
+    virtual void InternalClose();
+
     unsigned        sessionID;
     H323Listener  * listener;
     PBoolean            autoDeleteListener;
