@@ -23,13 +23,13 @@
  *
  * Contributor(s): Frbass Franz <franz.fuerbass@infonova.at>
  *
- * $Revision: 21004 $
+ * $Revision: 24092 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2010-03-04 00:22:29 -0600 (Thu, 04 Mar 2010) $
  */
 
-#ifndef __OPAL_H235AUTH_H
-#define __OPAL_H235AUTH_H
+#ifndef OPAL_H323_H235AUTH_H
+#define OPAL_H323_H235AUTH_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -37,6 +37,11 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_H323
+
+#include <ptlib/pfactory.h>
+
+
 class H323TransactionPDU;
 class H225_CryptoH323Token;
 class H225_ArrayOf_AuthenticationMechanism;
@@ -47,9 +52,6 @@ class PASN_ObjectId;
 class PASN_Sequence;
 class PASN_Array;
 
-namespace PWLibStupidLinkerHacks {
-extern int h235AuthLoader;
-};
 
 /** This abtract class embodies an H.235 authentication mechanism.
     NOTE: descendants must have a Clone() function for correct operation.
@@ -220,6 +222,8 @@ class H235AuthSimpleMD5 : public H235Authenticator
     ) const;
 };
 
+PFACTORY_LOAD(H235AuthSimpleMD5);
+
 
 /** This class embodies a RADIUS compatible based authentication (aka Cisco
     Access Token or CAT).
@@ -259,13 +263,11 @@ class H235AuthCAT : public H235Authenticator
     ) const;
 };
 
+PFACTORY_LOAD(H235AuthCAT);
+
 
 #if OPAL_PTLIB_SSL
 
-namespace PWLibStupidLinkerHacks {
-  extern int h235AuthProcedure1Loader;
-};
-
 /** This class embodies the H.235 "base line Procedure 1" from Annex D.
 */
 class H235AuthProcedure1 : public H235Authenticator
@@ -302,10 +304,13 @@ class H235AuthProcedure1 : public H235Authenticator
     virtual PBoolean UseGkAndEpIdentifiers() const;
 };
 
-#endif
+PFACTORY_LOAD(H235AuthProcedure1);
 
+#endif // OPAL_PTLIB_SSL
 
-#endif //__OPAL_H235AUTH_H
+#endif // OPAL_H323
+
+#endif //OPAL_H323_H235AUTH_H
 
 
 /////////////////////////////////////////////////////////////////////////////
