@@ -25,9 +25,9 @@
  *
  * The author of this code is Derek J Smithies
  *
- * $Revision: 21409 $
- * $Author: dereksmithies $
- * $Date: 2008-10-24 03:33:30 +0000 (Fri, 24 Oct 2008) $
+ * $Revision: 22799 $
+ * $Author: rjongbloed $
+ * $Date: 2009-06-03 07:13:44 -0500 (Wed, 03 Jun 2009) $
  */
 
 #ifndef OPAL_IAX2_MEDIASTRM_H
@@ -43,7 +43,6 @@
 
 #include <opal/mediafmt.h>
 #include <iax2/iax2con.h>
-#include <iax2/iax2jitter.h>
 
 class RTP_Session;
 class OpalMediaPatch;
@@ -114,11 +113,12 @@ class OpalIAX2MediaStream : public OpalMediaStream
       PINDEX & written     ///<Length of data actually written
     );
 
-    /**Indicate if the media stream is synchronous.
-       A synchronous stream is one that is regular, such as the sound frames
-       from a sound card.
+ /**Indicate if the media stream is synchronous.
+       @Return false if this stream is from the network.
+       @return true if this stream is from a sound card.
       */
     virtual PBoolean IsSynchronous() const;
+
   //@}
 
   protected:
