@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22675 $
+ * $Revision: 24076 $
  * $Author: rjongbloed $
- * $Date: 2009-05-20 04:23:29 +0000 (Wed, 20 May 2009) $
+ * $Date: 2010-02-23 21:06:41 -0600 (Tue, 23 Feb 2010) $
  */
 
 #ifndef OPAL_IM_IM_H
@@ -44,11 +44,10 @@ class OpalIMMediaType : public OpalMediaTypeDefinition
 {
   public:
     OpalIMMediaType(
-      const char * mediaType,          ///< name of the media type (audio, video etc)
-      const char * sdpType,            ///< name of the SDP type 
-      unsigned     preferredSessionId  ///< preferred session ID
+      const char * mediaType, ///< name of the media type (audio, video etc)
+      const char * sdpType    ///< name of the SDP type 
     )
-      : OpalMediaTypeDefinition(mediaType, sdpType, preferredSessionId, OpalMediaType::DontOffer)
+      : OpalMediaTypeDefinition(mediaType, sdpType, 0, OpalMediaType::DontOffer)
     { }
 
     PString GetRTPEncoding() const { return PString::Empty(); }
@@ -56,6 +55,22 @@ class OpalIMMediaType : public OpalMediaTypeDefinition
     virtual bool UsesRTP() const { return false; }
 };
 
+class RTP_IMFrame : public RTP_DataFrame
+{
+  public:
+    RTP_IMFrame();
+    RTP_IMFrame(const PString & contentType);
+    RTP_IMFrame(const PString & contentType, const T140String & content);
+    RTP_IMFrame(const BYTE * data, PINDEX len, PBoolean dynamic = PTrue);
+
+    void SetContentType(const PString & contentType);
+    PString GetContentType() const;
+
+    void SetContent(const T140String & text);
+    bool GetContent(T140String & text) const;
+
+    PString AsString() const { return PString((const char *)GetPayloadPtr(), GetPayloadSize()); }
+};
 
 class OpalIMMediaStream : public OpalMediaStream
 {
@@ -70,17 +85,10 @@ class OpalIMMediaStream : public OpalMediaStream
     virtual PBoolean IsSynchronous() const         { return false; }
     virtual PBoolean RequiresPatchThread() const   { return false; }
 
-    /*
-     * called to send IM to remote connection
-     */
-    virtual bool PushIM(const T140String & text);
-    virtual bool PushIM(RTP_DataFrame & frame);
-
-  protected:
-    RFC4103Context rfc4103;
+    bool ReadPacket(RTP_DataFrame & packet);
+    bool WritePacket(RTP_DataFrame & packet);
 };
 
-
 #endif // OPAL_HAS_IM
 
 #endif // OPAL_IM_IM_H
