@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21293 $
+ * $Revision: 23898 $
  * $Author: rjongbloed $
- * $Date: 2008-10-12 23:24:41 +0000 (Sun, 12 Oct 2008) $
+ * $Date: 2009-12-23 19:57:27 -0600 (Wed, 23 Dec 2009) $
  */
 
 #ifndef OPAL_LIDS_LIDPLUGINMGR_H
@@ -445,7 +445,7 @@ class OpalPluginLID : public OpalLineInterfaceDevice
        ID data, or if full is true, all of the fields in the caller ID data.
 
        The full data of the caller ID string consists fields separated by tab
-       characters ('\t'), the first three are always the Calling Line Identity
+       characters ('\\t'), the first three are always the Calling Line Identity
        (CLI or calling number), the date and the Calling Line Name field. Other
        fields may follow and are the of the form name=value. The values are
        LID dependent.
@@ -464,7 +464,7 @@ class OpalPluginLID : public OpalLineInterfaceDevice
        Identity.
 
        The full data of the caller ID string consists fields separated by tab
-       characters ('\t'), the first three are always the Calling Line Identity
+       characters ('\\t'), the first three are always the Calling Line Identity
        (CLI or calling number), the date and the Calling Line Name field. Other
        fields may follow and are the of the form name=value. The values are
        LID dependent.
@@ -504,7 +504,7 @@ class OpalPluginLID : public OpalLineInterfaceDevice
     );
 
     /**Read a DTMF digit detected.
-       This may be characters from the set 0-9, A-D, * or #. A null ('\0')
+       This may be characters from the set 0-9, A-D, * or #. A null ('\\0')
        character indicates that there are no tones in the queue.
        Characters E through P indicate the following tones:
 
@@ -663,4 +663,7 @@ class OpalPluginLID : public OpalLineInterfaceDevice
 };
 
 
+PFACTORY_LOAD(OpalPluginLIDManager);
+
+
 #endif // OPAL_LIDS_LIDPLUGINMGR_H
