@@ -27,9 +27,9 @@
  *     US Joint Forces Command Joint Concept Development & Experimentation (J9)
  *     http://www.jfcom.mil/about/abt_j9.htm
  *
- * $Revision: 24339 $
+ * $Revision: 24903 $
  * $Author: rjongbloed $
- * $Date: 2010-05-12 15:46:09 -0500 (Wed, 12 May 2010) $
+ * $Date: 2010-11-23 19:41:34 -0600 (Tue, 23 Nov 2010) $
  */
 
 #ifndef OPAL_OPAL_CONNECTION_H
@@ -305,15 +305,20 @@ class OpalProductInfo
 
     static OpalProductInfo & Default();
 
+    friend ostream & operator<<(ostream & strm, const OpalProductInfo & info);
     PCaselessString AsString() const;
 
-    PString vendor;
-    PString name;
-    PString version;
-    PString comments;
-    BYTE    t35CountryCode;
-    BYTE    t35Extension;
-    WORD    manufacturerCode;
+    PCaselessString vendor;
+    PCaselessString name;
+    PCaselessString version;
+    PCaselessString comments;
+
+    BYTE t35CountryCode;
+    BYTE t35Extension;
+    WORD manufacturerCode;
+
+  private:
+    OpalProductInfo(bool);
 };
 
 
@@ -1678,6 +1683,7 @@ class OpalConnection : public PSafeObject
     PString              localPartyName;
     PString              displayName;
     PString              remotePartyName;
+    PString              remotePartyURL;
     OpalProductInfo      remoteProductInfo;
     PString              remotePartyNumber;
     PString              remotePartyAddress;
