@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23926 $
+ * $Revision: 24442 $
  * $Author: rjongbloed $
- * $Date: 2010-01-12 18:44:33 -0600 (Tue, 12 Jan 2010) $
+ * $Date: 2010-06-02 03:17:31 -0500 (Wed, 02 Jun 2010) $
  */
 
 #ifndef OPAL_OPAL_ENDPOINT_H
@@ -766,6 +766,13 @@ class OpalEndPoint : public PObject
 };
 
 
+/// Test for if string is a valid E.164 number
+bool OpalIsE164(
+  const PString & number,   ///< Number to inspect
+  bool strict = false     ///< Strict interpretation, or allow leading '+'
+);
+
+
 #endif // OPAL_OPAL_ENDPOINT_H
 
 
