@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23973 $
+ * $Revision: 24684 $
  * $Author: rjongbloed $
- * $Date: 2010-01-24 18:33:51 -0600 (Sun, 24 Jan 2010) $
+ * $Date: 2010-09-07 22:22:44 -0500 (Tue, 07 Sep 2010) $
  */
 
 #ifndef OPAL_OPAL_PATCH_H
@@ -198,6 +198,12 @@ class OpalMediaPatch : public PObject
       PBoolean fromSink                 ///<  Flag for source or sink
     );
 
+    /**Set streams to paused.
+      */
+    virtual void SetPaused(
+      bool pause
+    );
+
     /**Push a frame out to all the sink streams, transcoding as necessary.
       */
     virtual PBoolean PushFrame(
@@ -260,11 +266,15 @@ class OpalMediaPatch : public PObject
 
         OpalMediaPatch  &  patch;
         OpalMediaStreamPtr stream;
-        OpalTranscoder  * primaryCodec;
-        OpalTranscoder  * secondaryCodec;
-        RTP_DataFrameList intermediateFrames;
-        RTP_DataFrameList finalFrames;
-        bool              writeSuccessful;
+        OpalTranscoder   * primaryCodec;
+        OpalTranscoder   * secondaryCodec;
+        RTP_DataFrameList  intermediateFrames;
+        RTP_DataFrameList  finalFrames;
+        bool               writeSuccessful;
+
+        RTP_DataFrame::PayloadTypes m_lastPayloadType;
+        unsigned                    m_consecutivePayloadTypeMismatches;
+        bool CannotTranscodeFrame(OpalTranscoder & codec, RTP_DataFrame & frame);
 
 #if OPAL_VIDEO
         void SetRateControlParameters(const OpalMediaFormat & mediaFormat);
