@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21817 $
+ * $Revision: 24127 $
  * $Author: rjongbloed $
- * $Date: 2008-12-17 03:08:52 +0000 (Wed, 17 Dec 2008) $
+ * $Date: 2010-03-14 18:12:08 -0500 (Sun, 14 Mar 2010) $
  */
 
 #ifndef OPAL_RTP_RTP_H
@@ -41,6 +41,8 @@
 #include <opal/buildopts.h>
 
 #include <ptlib/sockets.h>
+#include <ptlib/safecoll.h>
+
 
 class RTP_JitterBuffer;
 class PNatMethod;
@@ -68,7 +70,7 @@ class RTP_DataFrame : public PBYTEArray
   PCLASSINFO(RTP_DataFrame, PBYTEArray);
 
   public:
-    RTP_DataFrame(PINDEX payloadSize = 2048);
+    RTP_DataFrame(PINDEX payloadSize = 0, PINDEX bufferSize = 0);
     RTP_DataFrame(const BYTE * data, PINDEX len, PBoolean dynamic = PTrue);
 
     enum {
@@ -108,6 +110,8 @@ class RTP_DataFrame : public PBYTEArray
       MP2T,         // MPEG2 transport system
       H263,         // H.263
 
+      T38 = 38,     // T.38 (internal)
+
       LastKnownPayloadType,
 
       DynamicBase = 96,
@@ -148,8 +152,8 @@ class RTP_DataFrame : public PBYTEArray
 
     int GetExtensionType() const; // -1 is no extension
     void   SetExtensionType(int type);
-    PINDEX GetExtensionSize() const;
-    PBoolean   SetExtensionSize(PINDEX sz);
+    PINDEX GetExtensionSizeDWORDs() const;      // get the number of 32 bit words in the extension (excluding the header).
+    bool   SetExtensionSizeDWORDs(PINDEX sz);   // set the number of 32 bit words in the extension (excluding the header)
     BYTE * GetExtensionPtr() const;
 
     PINDEX GetPayloadSize() const { return payloadSize - GetPaddingSize(); }
@@ -308,6 +312,31 @@ class OpalMediaStatistics : public PObject
     // Video
     unsigned m_totalFrames;
     unsigned m_keyFrames;
+
+    // Fax
+#if OPAL_FAX
+    struct Fax {
+      Fax();
+
+      int  m_result;      // -2=not started, -1=progress, 0=success, >0=ended with error
+      int  m_bitRate;     // e.g. 14400, 9600
+      int  m_compression; // 0=N/A, 1=T.4 1d, 2=T.4 2d, 3=T.6
+      bool m_errorCorrection;
+      int  m_txPages;
+      int  m_rxPages;
+      int  m_totalPages;
+      int  m_imageSize;   // In bytes
+      int  m_resolutionX; // Pixels per inch
+      int  m_resolutionY; // Pixels per inch
+      int  m_pageWidth;
+      int  m_pageHeight;
+      int  m_badRows;     // Total number of bad rows
+      int  m_mostBadRows; // Longest run of bad rows
+      int  m_errorCorrectionRetries;
+
+      PString m_errorText;
+    } m_fax;
+#endif
 };
 
 #endif
@@ -414,19 +443,17 @@ class RTP_Session : public PObject
   /**@name Operations */
   //@{
     /**Sets the size of the jitter buffer to be used by this RTP session.
-       A session default to not having any jitter buffer enabled for reading
-       and the ReadBufferedData() function simply calls ReadData(). Once a
-       jitter buffer has been created it cannot be removed, though its size
-       may be adjusted.
-       
-       If the jitterDelay paramter is zero, it destroys the jitter buffer
+       A session defaults to not having any jitter buffer enabled for reading
+       and the ReadBufferedData() function simply calls ReadData().
+
+       If either jitter delay parameter is zero, it destroys the jitter buffer
        attached to this RTP session.
       */
     void SetJitterBufferSize(
       unsigned minJitterDelay, ///<  Minimum jitter buffer delay in RTP timestamp units
       unsigned maxJitterDelay, ///<  Maximum jitter buffer delay in RTP timestamp units
-      unsigned timeUnits = 8,  ///<  Time Units
-      PINDEX stackSize = 30000 ///<  Stack size for jitter thread
+      unsigned timeUnits = 0,  ///<  Time Units, zero uses default
+      PINDEX packetSize = 2048 ///<  Receive RTP packet size
     );
 
     /**Get current size of the jitter buffer.
@@ -438,7 +465,7 @@ class RTP_Session : public PObject
     
     /**Get current time units of the jitter buffer.
      */
-    unsigned GetJitterTimeUnits() const;
+    unsigned GetJitterTimeUnits() const { return m_timeUnits; }
 
     /**Modifies the QOS specifications for this RTP session*/
     virtual PBoolean ModifyQOS(RTP_QOS * )
@@ -489,7 +516,7 @@ class RTP_Session : public PObject
 
     /**Close down the RTP session.
       */
-    virtual void Close(
+    virtual bool Close(
       PBoolean reading    ///<  Closing the read side of the session
     ) = 0;
 
@@ -556,6 +583,7 @@ class RTP_Session : public PObject
                                   const ReceiverReportArray & reports);
     virtual void OnRxReceiverReport(DWORD src,
                                     const ReceiverReportArray & reports);
+    virtual void OnReceiverReports(const ReceiverReportArray & reports);
 
     class SourceDescription : public PObject  {
         PCLASSINFO(SourceDescription, PObject);
@@ -582,6 +610,10 @@ class RTP_Session : public PObject
       */
     unsigned GetSessionID() const { return sessionID; }
 
+    /**Set the ID for the RTP session.
+      */
+    void SetSessionID(unsigned id) { sessionID = id; }
+
     /**Get flag for is audio RTP.
       */
     bool IsAudio() const { return isAudio; }
@@ -708,6 +740,11 @@ class RTP_Session : public PObject
       */
     DWORD GetPacketsLost() const { return packetsLost; }
 
+    /**Get total number transmitted packets lost by remote in session.
+       Determined via RTCP.
+      */
+    DWORD GetPacketsLostByRemote() const { return packetsLostByRemote; }
+
     /**Get total number of packets received out of order in session.
       */
     DWORD GetPacketsOutOfOrder() const { return packetsOutOfOrder; }
@@ -768,24 +805,23 @@ class RTP_Session : public PObject
       */
     DWORD GetMinimumReceiveTime() const { return minimumReceiveTime; }
 
+    enum { JitterRoundingGuardBits = 4 };
     /**Get averaged jitter time for received packets.
        This is the calculated statistical variance of the interarrival
        time of received packets in milliseconds.
       */
-    DWORD GetAvgJitterTime() const { return jitterLevel>>7; }
+    DWORD GetAvgJitterTime() const { return (jitterLevel>>JitterRoundingGuardBits)/GetJitterTimeUnits(); }
 
     /**Get averaged jitter time for received packets.
        This is the maximum value of jitterLevel for the session.
       */
-    DWORD GetMaxJitterTime() const { return maximumJitterLevel>>7; }
-  //@}
+    DWORD GetMaxJitterTime() const { return (maximumJitterLevel>>JitterRoundingGuardBits)/GetJitterTimeUnits(); }
 
-  /**@name Functions added to support RTP aggregation */
-  //@{
-    virtual int GetDataSocketHandle() const
-    { return -1; }
-    virtual int GetControlSocketHandle() const
-    { return -1; }
+    /**Get jitter time for received packets on remote.
+       This is the calculated statistical variance of the interarrival
+       time of received packets in milliseconds.
+      */
+    DWORD GetJitterTimeOnRemote() const { return jitterLevelOnRemote/GetJitterTimeUnits(); }
   //@}
 
     virtual void SetCloseOnBYE(PBoolean v)  { closeOnBye = v; }
@@ -837,11 +873,14 @@ class RTP_Session : public PObject
 
     unsigned           sessionID;
     bool               isAudio;
+    unsigned           m_timeUnits;
     PString            canonicalName;
     PString            toolName;
     RTP_UserData     * userData;
     PBoolean           autoDeleteUserData;
-    RTP_JitterBuffer * jitter;
+
+    typedef PSafePtr<RTP_JitterBuffer, PSafePtrMultiThreaded> JitterBufferPtr;
+    JitterBufferPtr m_jitterBuffer;
 
     PBoolean      ignoreOutOfOrderPackets;
     DWORD         syncSourceOut;
@@ -874,6 +913,7 @@ class RTP_Session : public PObject
     DWORD packetsReceived;
     DWORD octetsReceived;
     DWORD packetsLost;
+    DWORD packetsLostByRemote;
     DWORD packetsOutOfOrder;
     DWORD averageSendTime;
     DWORD maximumSendTime;
@@ -882,6 +922,7 @@ class RTP_Session : public PObject
     DWORD maximumReceiveTime;
     DWORD minimumReceiveTime;
     DWORD jitterLevel;
+    DWORD jitterLevelOnRemote;
     DWORD maximumJitterLevel;
 
     DWORD markerSendCount;
@@ -963,7 +1004,7 @@ class RTP_UDP : public RTP_Session
 
     /**Close down the RTP session.
       */
-    virtual void Close(
+    virtual bool Close(
       PBoolean reading    ///<  Closing the read side of the session
     );
 
@@ -1115,10 +1156,11 @@ class RTP_Encoding
   public:
     RTP_Encoding();
     virtual ~RTP_Encoding();
+    virtual void ApplyStringOptions(const PStringToString & /*stringOptions*/) {}
     virtual void OnStart(RTP_Session & _rtpSession);
     virtual void OnFinish();
     virtual RTP_Session::SendReceiveStatus OnSendData(RTP_DataFrame & frame);
-    virtual PBoolean WriteData(RTP_DataFrame & frame);
+    virtual PBoolean WriteData(RTP_DataFrame & frame, bool oob);
     virtual PBoolean WriteDataPDU(RTP_DataFrame & frame);
     virtual RTP_Session::SendReceiveStatus OnSendControl(RTP_ControlFrame & frame, PINDEX & len);
     virtual RTP_Session::SendReceiveStatus ReadDataPDU(RTP_DataFrame & frame);
@@ -1134,6 +1176,9 @@ class RTP_Encoding
     RTP_UDP     * rtpUDP;
 };
 
+PFACTORY_LOAD(RTP_Encoding);
+
+
 /////////////////////////////////////////////////////////////////////////////
 
 class SecureRTP_UDP : public RTP_UDP
