@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24536 $
+ * $Revision: 24913 $
  * $Author: rjongbloed $
- * $Date: 2010-06-23 22:15:38 -0500 (Wed, 23 Jun 2010) $
+ * $Date: 2010-11-30 16:22:28 -0600 (Tue, 30 Nov 2010) $
  */
 
 #ifndef OPAL_SIP_SIPCON_H
@@ -57,8 +57,11 @@
 class OpalCall;
 class SIPEndPoint;
 
-#define SIP_HEADER_PREFIX   "SIP-Header:"
-#define SIP_HEADER_REPLACES SIP_HEADER_PREFIX"Replaces"
+#define SIP_HEADER_PREFIX      "SIP-Header:"
+#define SIP_HEADER_REPLACES    SIP_HEADER_PREFIX"Replaces"
+#define SIP_HEADER_CONTACT     SIP_HEADER_PREFIX"Contact"
+
+#define OPAL_OPT_SYMMETRIC_HOLD_PRODUCT "Symmetric-Hold-Product"
 
 
 /////////////////////////////////////////////////////////////////////////
@@ -110,14 +113,6 @@ class SIPConnection : public OpalRTPConnection
      */
     virtual PString GetIdentifier() const;
 
-    /**Get the remote party address as URL.
-       This will return the "best guess" at an address to use in a
-       to call the user again later. Note that under some circumstances this may be
-       different to the value GetRemotePartyAddress() value returns. In particular
-       if a gatekeeper is involved.
-      */
-    virtual PString GetRemotePartyURL() const;
-
     /**Start an outgoing connection.
        This function will initiate the connection to the remote entity, for
        example in H.323 it sends a SETUP, in SIP it sends an INVITE etc.
@@ -579,6 +574,7 @@ class SIPConnection : public OpalRTPConnection
 
     PTimer                    ackTimer;
     PTimer                    ackRetry;
+    unsigned                  ackRetryCount;
     SIP_PDU                   ackPacket;
     bool                      ackReceived;
     bool                      m_referInProgress;
