@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23284 $
+ * $Revision: 24074 $
  * $Author: rjongbloed $
- * $Date: 2009-08-28 00:16:56 +0000 (Fri, 28 Aug 2009) $
+ * $Date: 2010-02-23 20:36:11 -0600 (Tue, 23 Feb 2010) $
  */
 
 #ifndef OPAL_SIP_SIPEP_H
@@ -57,6 +57,11 @@
 class SIPRegisterHandler;
 
 
+//
+//  provide flag so applications know if presence is available
+//
+#define OPAL_HAS_SIP_PRESENCE   1
+
 /////////////////////////////////////////////////////////////////////////
 
 /** Class to hold authentication information 
@@ -146,7 +151,7 @@ class SIPEndPoint : public OpalRTPEndPoint
 
        The default behaviour is pure.
      */
-    virtual PBoolean MakeConnection(
+    virtual PSafePtr<OpalConnection> MakeConnection(
       OpalCall & call,                         ///<  Owner of connection
       const PString & party,                   ///<  Remote party to call
       void * userData,                         ///<  Arbitrary data to pass to connection
@@ -217,6 +222,22 @@ class SIPEndPoint : public OpalRTPEndPoint
       const PString & forwardParty    ///<  Remote party to forward to
     );
 
+    /**Clear a SIP connection by dialog identifer informataion.
+       This function does not require an OPAL connection to operate, it will
+       attempt to send a BYE to the dialog identified by the information in
+       the SIPDialogContext structure.
+
+       This feature can be useful for servers that had an "unexpected exit"
+       and various clients it was talking to at the time do not implement the
+       RFC4028 session timers, so continue to try and send media forever. They
+       need to be told to cease and desist.
+      */
+    bool ClearDialogContext(
+      const PString & descriptor  ///< Descriptor string for call clearance
+    );
+    bool ClearDialogContext(
+      SIPDialogContext & context  ///< Context for call clearance
+    );
   //@}
   
   /**@name Protocol handling routines */
@@ -333,31 +354,47 @@ class SIPEndPoint : public OpalRTPEndPoint
     virtual PBoolean IsAcceptedAddress(const SIPURL & toAddr);
 
 
-    /**Callback for SIP message received
-     */
-    virtual void OnMessageReceived (const SIPURL & from, const PString & body);
-    virtual void OnMessageReceived (const SIPURL & from, const SIP_PDU & pdu);
+    /**Register an entity to a registrar.
+       This function is asynchronous to permit several registrations to occur
+       at the same time. It can be called several times for different hosts
+       and users.
 
-    /**Register to a registrar. This function is asynchronous to permit
-       several registrations to occur at the same time. It can be
-       called several times for different hosts and users.
-       
-       The username can be of the form user@domain. In that case,
-       the address-of-record field will be set to that value. If not then
-       the address-of-record is constructed from the user and host fields.
-       
-       The realm can be specified when registering, this will
+       The params.m_addressOfRecord field is the only field required, though
+       typically params.m_password is also required. A registration for the
+       user part of params.m_addressOfRecord is made to the a registrar
+       associated with the domain part of the field. The authentication
+       identity is the same as the user field, though this may be set to
+       soemthing different via the params.m_authID field.
+
+       The params.m_registrarAddress may indicate the specific hostname to use
+       for the registrar rather than using the domain part of
+       params.m_addressOfRecord field.
+
+       To aid in flexbility if the params.m_addressOfRecord does not contain
+       a domain and the params.m_registrarAddress does, the the AOR is
+       constructed from them.
+
+       The params.m_realm can be specified when registering, this will
        allow to find the correct authentication information when being
        requested. If no realm is specified, authentication will
        occur with the "best guess" of authentication parameters.
+
+       The Contact address is normally constructed from the listeners active
+       on the SIPEndPoint. This may be overridden to an explicit value via the
+       params.m_contactAddress field.
+
+       The returned "token" is a string that can be used in functions
+       such as Unregister() or IsRegistered(). While it possible to use the
+       AOR for those functions, it is not recommended as a) there may be more
+       than one registration for an AOR and b) the AOR may be constructed from
      */
     bool Register(
-      const SIPRegister::Params & params, ///< Registration paarameters
+      const SIPRegister::Params & params, ///< Registration parameters
       PString & aor                       ///< Resultant address-of-record for unregister
     );
 
     /// Registration function for backward compatibility.
-    bool Register(
+    bool P_DEPRECATED Register(
       const PString & host,
       const PString & user = PString::Empty(),
       const PString & autName = PString::Empty(),
@@ -368,28 +405,43 @@ class SIPEndPoint : public OpalRTPEndPoint
       const PTimeInterval & maxRetryTime = PMaxTimeInterval
     );
 
-    /**Unregister from a registrar.
-       This will unregister the specified address-of-record. If an empty
-       string is provided then ALL registrations are removed.
-     */
-    bool Unregister(const PString & aor);
+    /**Determine if there is a registration for the entity.
+       The "token" parameter string is typically the string returned by the
+       Register() function which is guaranteed to uniquely identify the
+       specific registration.
 
-    /**Unregister all current registrations.
-       Returns true if at least one registra is unregistered.
-      */
-    bool UnregisterAll();
+       For backward compatibility, the AOR can also be used, but as it is
+       possible to have two registrations to the same AOR, this should be
+       avoided.
 
-    /**Returns PTrue if the given URL has been registered 
-     * (e.g.: 6001@seconix.com). The includeOffline parameter indicates
-       if the caller is interested in if we are, to the best of our knowlegde,
-       currently registered (have had recent confirmation) or we are not sure
-       if we are registered or not, but are continually re-trying.
+       The includeOffline parameter indicates if the caller is interested in
+       if we are, to the best of our knowledge, currently registered (have
+       had recent confirmation) or we are not sure if we are registered or
+       not, but are continually re-trying.
      */
     PBoolean IsRegistered(
-      const PString & aor,          ///< Address of record to check
+      const PString & aor,          ///< AOR returned by Register()
       bool includeOffline = false   ///< Include offline registrations
     );
 
+    /**Unregister the address-of-record from a registrar.
+       The "token" parameter string is typically the string returned by the
+       Register() function which is guaranteed to uniquely identify the
+       specific registration.
+
+       For backward compatibility, the AOR can also be used, but as it is
+       possible to have two registrations to the same AOR, this should be
+       avoided.
+     */
+    bool Unregister(
+      const PString & aor    ///< AOR returned by Register()
+    );
+
+    /**Unregister all current registrations.
+       Returns true if at least one registrar is unregistered.
+      */
+    bool UnregisterAll();
+
     /** Returns the number of registered accounts.
      */
     unsigned GetRegistrationsCount() const { return activeSIPHandlers.GetCount(SIP_PDU::Method_REGISTER); }
@@ -402,6 +454,7 @@ class SIPEndPoint : public OpalRTPEndPoint
 
     /** Information provided on the registration status. */
     struct RegistrationStatus {
+      SIPRegisterHandler * m_handler;           ///< Handler for registration
       PString              m_addressofRecord;   ///< Address of record for registration
       bool                 m_wasRegistering;    ///< Was registering or unregistering
       bool                 m_reRegistering;     ///< Was a registration refresh
@@ -442,21 +495,86 @@ class SIPEndPoint : public OpalRTPEndPoint
     );
 
 
-    /**Subscribe to a notifier. This function is asynchronous to permit
-     * several subscriptions to occur at the same time.
+    /**Subscribe to an agent to get event notifications.
+       This function is asynchronous to permit several subscriptions to occur
+       at the same time. It can be called several times for different hosts
+       and users.
+
+       The params.m_eventPackage and params.m_addressOfRecord field are the
+       only field required, though typically params.m_password is also
+       required. A subscription for the user part of params.m_addressOfRecord
+       is made to the an agent associated with the domain part of the field.
+       The authentication identity is the same as the user field, though this
+       may be set to soemthing different via the params.m_authID field.
+
+       The params.m_agentAddress may indicate the specific hostname to use
+       for the registrar rather than using the domain part of
+       params.m_addressOfRecord field.
+
+       To aid in flexbility if the params.m_addressOfRecord does not contain
+       a domain and the params.m_agentAddress does, the the AOR is
+       constructed from them.
+
+       The params.m_realm can be specified when subcribing, this will
+       allow to find the correct authentication information when being
+       requested. If no realm is specified, authentication will
+       occur with the "best guess" of authentication parameters.
+
+       The Contact address is normally constructed from the SIPEndPoint local
+       identity.
+
+       The returned "token" is a string that can be used in functions
+       such as Unregister() or IsRegistered(). While it possible to use the
+       user supplied AOR for those functions, it is not recommended as a) there
+       may be more than one registration for an AOR and b) the AOR may be
+       constructed from fields in the params argument and not be what the user
+       expects.
+
+       The tokenIsAOR can also be used, if false, to return the globally unique
+       ID used for the handler. This is the preferred method, even though the
+       default is to not use it, that is for backward compatibility reasons.
      */
+    bool Subscribe(
+      const SIPSubscribe::Params & params, ///< Subscription parameters
+      PString & token,                     ///< Resultant token for unsubscribe
+      bool tokenIsAOR = true               ///< Token is the address-of-record
+    );
+
+    // For backward compatibility
     bool Subscribe(
       SIPSubscribe::PredefinedPackages eventPackage, ///< Event package being unsubscribed
       unsigned expire,                               ///< Expiry time in seconds
       const PString & aor                            ///< Address-of-record for subscription
     );
-    bool Subscribe(
-      const SIPSubscribe::Params & params, ///< Subscription paarameters
-      PString & aor                        ///< Resultant address-of-record for unsubscribe
+
+    /**Returns true if the endpoint is subscribed to some
+       event for the given to address. The includeOffline parameter indicates
+       if the caller is interested in if we are, to the best of our knowlegde,
+       currently subscribed (have had recent confirmation) or we are not sure
+       if we are subscribed or not, but are continually re-trying.
+     */
+    bool IsSubscribed(
+      const PString & aor,           ///< AOR returned by Subscribe()
+      bool includeOffline = false    ///< Include offline subscription
+    );
+    bool IsSubscribed(
+      const PString & eventPackage,  ///< Event package being unsubscribed
+      const PString & aor,           ///< Address-of-record for subscription
+      bool includeOffline = false    ///< Include offline subscription
     );
 
     /**Unsubscribe a current subscriptions.
+       The "token" parameter string is typically the string returned by the
+       Subscribe() function which is guaranteed to uniquely identify the
+       specific registration.
+
+       For backward compatibility, the AOR can also be used, but as it is
+       possible to have two susbcriptions to the same AOR, this should be
+       avoided.
       */
+    bool Unsubscribe(
+      const PString & aor          ///< Unique token for registration
+    );
     bool Unsubscribe(
       SIPSubscribe::PredefinedPackages eventPackage,  ///< Event package being unsubscribed
       const PString & aor                             ///< Address-of-record for subscription
@@ -476,18 +594,6 @@ class SIPEndPoint : public OpalRTPEndPoint
       const PString & eventPackage  ///< Event package being unsubscribed
     );
 
-    /**Returns true if the endpoint is subscribed to some
-       event for the given to address. The includeOffline parameter indicates
-       if the caller is interested in if we are, to the best of our knowlegde,
-       currently subscribed (have had recent confirmation) or we are not sure
-       if we are subscribed or not, but are continually re-trying.
-     */
-    PBoolean IsSubscribed(
-      const PString & eventPackage,  ///< Event package being unsubscribed
-      const PString & aor,           ///< Address-of-record for subscription
-      bool includeOffline = false    ///< Include offline subscriptions
-    );
-
     /** Returns the number of registered accounts.
      */
     unsigned GetSubscriptionCount(
@@ -501,8 +607,18 @@ class SIPEndPoint : public OpalRTPEndPoint
       bool includeOffline = false   ///< Include offline subscriptions
     ) const { return activeSIPHandlers.GetAddresses(includeOffline, SIP_PDU::Method_REGISTER, eventPackage); }
 
+    /** Information provided on the subscription status. */
+    typedef SIPSubscribe::SubscriptionStatus SubscriptionStatus;
+
     /**Callback called when a subscription to a SIP UA status changes.
      */
+    virtual void OnSubscriptionStatus(
+      const SubscriptionStatus & status   ///< Status of subscription request
+    );
+
+    /**Callback called when a subscription to a SIP UA status changes.
+       Now deprecated - called by OnSubscriptionStatus that accepts SIPHandler
+     */
     virtual void OnSubscriptionStatus(
       const PString & eventPackage, ///< Event package subscribed to
       const SIPURL & uri,           ///< Target URI for the subscription.
@@ -511,6 +627,14 @@ class SIPEndPoint : public OpalRTPEndPoint
       SIP_PDU::StatusCodes reason   ///< Status of subscription
     );
 
+    virtual void OnSubscriptionStatus(
+      SIPSubscribeHandler & handler, /// event subscription paramaters
+      const SIPURL & uri,            ///< Target URI for the subscription.
+      bool wasSubscribing,           ///< Indication the subscribing or unsubscribing
+      bool reSubscribing,            ///< If subscribing then indication was refeshing subscription
+      SIP_PDU::StatusCodes reason    ///< Status of subscription
+    );
+
     /** Indicate notifications for the specified event package are supported.
       */
     virtual bool CanNotify(
@@ -536,20 +660,16 @@ class SIPEndPoint : public OpalRTPEndPoint
       const SIPDialogNotification & info  ///< Information on dialog state change
     );
 
-
-    /**Send a message to the given URL.
+    /**Send SIP message
      */
-    PBoolean Message(
-      const PString & to, 
-      const PString & body
-    );
-    PBoolean Message(
-      const PString & to, 
+    virtual bool Message(
+      const PURL & to, 
+      const PString & type,
       const PString & body,
-      const PString & remoteContact, 
-      const PString & callID
+      PURL & from,
+      PString & conversationId
     );
-    
+
     /**Callback called when a message sent by the endpoint didn't reach
      * its destination or when the proxy or remote endpoint returns
      * an error code.
@@ -605,7 +725,7 @@ class SIPEndPoint : public OpalRTPEndPoint
     /**Send a SIP PING to the remote host
       */
     PBoolean Ping(
-      const PString & to
+      const PURL & to
     );
 
 
@@ -637,6 +757,11 @@ class SIPEndPoint : public OpalRTPEndPoint
     ) { inviteTimeout = t; }
     const PTimeInterval & GetInviteTimeout() const { return inviteTimeout; }
 
+    void SetProgressTimeout(
+      const PTimeInterval & t
+    ) { m_progressTimeout = t; }
+    const PTimeInterval & GetProgressTimeout() const { return m_progressTimeout; }
+
     void SetAckTimeout(
       const PTimeInterval & t
     ) { ackTimeout = t; }
@@ -670,8 +795,12 @@ class SIPEndPoint : public OpalRTPEndPoint
 
     /**Return the SIPAuthentication for a specific realm.
      */
-    PBoolean GetAuthentication(const PString & authRealm, PString & realm, PString & user, PString & password); 
+    bool GetAuthentication(const PString & authRealm, PString & user, PString & password); 
     
+    /**Return the registered proxy URL for the given host.
+     */
+    virtual SIPURL GetRegisteredProxy(const SIPURL & remoteURL);
+
     /**Return the registered party name URL for the given host.
      *
      * That URL can be used in the FORM field of the PDU's. 
@@ -781,8 +910,9 @@ class SIPEndPoint : public OpalRTPEndPoint
     virtual OpalSIPIMManager & GetSIPIMManager() { return m_sipIMManager; }
 #endif
 
+    void UpdateHandlerIndexes(SIPHandler * handler) { activeSIPHandlers.Update(handler); }
+
   protected:
-    void TransportReadLoop(OpalTransport * transport);
     PDECLARE_NOTIFIER(PThread, SIPEndPoint, TransportThreadMain);
     PDECLARE_NOTIFIER(PTimer, SIPEndPoint, NATBindingRefresh);
 
@@ -796,6 +926,7 @@ class SIPEndPoint : public OpalRTPEndPoint
     PTimeInterval nonInviteTimeout;  // T3
     PTimeInterval pduCleanUpTimeout; // T4
     PTimeInterval inviteTimeout;
+    PTimeInterval m_progressTimeout;
     PTimeInterval ackTimeout;
     PTimeInterval registrarTimeToLive;
     PTimeInterval notifierTimeToLive;
@@ -812,34 +943,37 @@ class SIPEndPoint : public OpalRTPEndPoint
     PAtomicInteger          lastSentCSeq;
     int                     m_defaultAppearanceCode;
 
-    struct SIP_PDU_Work
+  public:
+    class WorkThreadPool;
+    class SIP_Work
     {
       public:
-        SIP_PDU_Work(SIPEndPoint & ep, const PString & token, SIP_PDU * pdu);
-        ~SIP_PDU_Work();
+        SIP_Work(SIPEndPoint & ep, SIP_PDU * pdu, const PString & token);
+        virtual ~SIP_Work();
 
-        void OnReceivedPDU();
+        virtual void Process();
 
         SIPEndPoint & m_endpoint;
-        PString       m_token;
         SIP_PDU     * m_pdu;
+        PString       m_token;
     };
 
-    class PDUThreadPool : public PThreadPool<SIP_PDU_Work>
+    class WorkThreadPool : public PThreadPool<SIP_Work>
     {
       public:
         virtual WorkerThreadBase * CreateWorkerThread();
     } m_connectionThreadPool, m_handlerThreadPool;
 
-    typedef std::queue<SIP_PDU_Work *> SIP_PDUWorkQueue;
+  protected:
+    typedef std::queue<SIP_Work *> SIP_WorkQueue;
 
-    class SIP_PDU_Thread : public PDUThreadPool::WorkerThread
+    class SIP_Work_Thread : public WorkThreadPool::WorkerThread
     {
       public:
-        SIP_PDU_Thread(PDUThreadPool & pool_);
+        SIP_Work_Thread(WorkThreadPool & pool_);
 
-        void AddWork(SIP_PDU_Work * work);
-        void RemoveWork(SIP_PDU_Work * work);
+        void AddWork(SIP_Work * work);
+        void RemoveWork(SIP_Work * work);
         unsigned GetWorkSize() const;
 
         void Main();
@@ -847,7 +981,7 @@ class SIPEndPoint : public OpalRTPEndPoint
 
       protected:
         PSyncPoint m_sync;
-        SIP_PDUWorkQueue m_pduQueue;
+        SIP_WorkQueue m_pduQueue;
     };
 
     enum {
@@ -881,6 +1015,29 @@ class SIPEndPoint : public OpalRTPEndPoint
     P_REMOVE_VIRTUAL_VOID(OnReceivedIntervalTooBrief(SIPTransaction &, SIP_PDU &));
     P_REMOVE_VIRTUAL_VOID(OnReceivedAuthenticationRequired(SIPTransaction &, SIP_PDU &));
     P_REMOVE_VIRTUAL_VOID(OnReceivedOK(SIPTransaction &, SIP_PDU &));
+
+  public:
+    struct ConnectionlessMessageInfo {
+      ConnectionlessMessageInfo(OpalTransport & transport, SIP_PDU & pdu)
+        : m_pdu(pdu), m_transport(transport), m_status(true)
+      { }
+
+      SIP_PDU & m_pdu;
+      OpalTransport & m_transport;
+      bool m_status;
+    };
+
+    typedef PNotifierTemplate<ConnectionlessMessageInfo &> ConnectionlessMessageNotifier;
+    #define PDECLARE_ConnectionlessMessageNotifier(cls, fn) PDECLARE_NOTIFIER2(SIPEndPoint, cls, fn, SIPEndPoint::ConnectionlessMessageInfo &)
+    #define PCREATE_ConnectionlessMessageNotifier(fn) PCREATE_NOTIFIER2(fn, SIPEndPoint::ConnectionlessMessageInfo &)
+
+    void SetConnectionlessMessageNotifier(
+      const ConnectionlessMessageNotifier & notifier
+    )
+    { m_onConnectionlessMessage = notifier; }
+
+  protected:
+    ConnectionlessMessageNotifier m_onConnectionlessMessage;
 };
 
 
