@@ -21,9 +21,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21293 $
+ * $Revision: 23321 $
  * $Author: rjongbloed $
- * $Date: 2008-10-12 18:24:41 -0500 (Sun, 12 Oct 2008) $
+ * $Date: 2009-09-03 06:05:04 -0500 (Thu, 03 Sep 2009) $
  */
 
 #ifndef _Jester_MAIN_H
@@ -41,18 +41,6 @@
 #include <rtp/jitter.h>
 #include <rtp/rtp.h>
 
-/** We use the IAX2 jitter buffer, as it is close to what we need, and has no
-    RTP session stuff to worry about. The iax2 jitter buffer is derived from
-    the OpalJitterBuffer, and demands OPAL library code newer than Jan 2007 */
-
-/**** Note, this code will only compile if you use an OPAL library code newer
-    than January 2007 */
-#include <iax2/iax2jitter.h>   
-/**** Note, this code will only compile if you use an OPAL library code newer
-    than January 2007 */
-
-
-
 #include <ptclib/delaychan.h>
 #include <ptclib/random.h>
 
@@ -63,9 +51,9 @@
 
 /////////////////////////////////////////////////////////////////////////////
 /**we use this class primarily to access variables in the OpalJitterBuffer*/
-class JesterJitterBuffer : public IAX2JitterBuffer
+class JesterJitterBuffer : public OpalJitterBuffer
 {
-    PCLASSINFO(JesterJitterBuffer, IAX2JitterBuffer);
+    PCLASSINFO(JesterJitterBuffer, OpalJitterBuffer);
  public:
     JesterJitterBuffer();
 
@@ -75,46 +63,7 @@ class JesterJitterBuffer : public IAX2JitterBuffer
     DWORD GetTargetJitterTime() { return targetJitterTime; }
 
     /**Report the current jitter depth */
-    unsigned GetCurrentDepth() { return jitterBuffer.size(); }
-
-    /** repot on an internal variable */
-    DWORD GetCurrentJitterTime() { return currentJitterTime; }
-
-
-    virtual void Close(
-	PBoolean /*reading */   ///<  Closing the read side of the session
-	);
-
-   /**Reopens an existing session in the given direction.
-      */
-    virtual void Reopen(
-	PBoolean /*isReading */
-	) { }
-
-    /**Get the local host name as used in SDES packes.
-      */
-    virtual PString GetLocalHostName() { return PString("Jester"); }
-
-
-
- protected:
-    /**psuedo sequence number that we will put into the packets */
-    WORD psuedoSequenceNo;
-
-    /**psuedo timestamp that we will put into the packets. Timestamp goes up
-     * by the number of samples placed in the packet. So, 8khz, 30ms duration,
-     * means 240 increment for each packet. */
-    DWORD psuedoTimestamp;
-
-    /**Flag to indicate we have closed down */
-    PBoolean closedDown;
-
-    /**time at which this all started */
-    PTime startJester;
-
-    /**Number of times we have read a packet. This is required to determine the required time period
-       to sleep */
-    PINDEX readCount;
+    PINDEX GetCurrentDepth() { return jitterBuffer.GetSize(); }
 };
 
 /////////////////////////////////////////////////////////////////////////////
