@@ -24,24 +24,26 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22664 $
+ * $Revision: 24050 $
  * $Author: rjongbloed $
- * $Date: 2009-05-19 10:23:00 +0000 (Tue, 19 May 2009) $
+ * $Date: 2010-02-10 17:55:17 -0600 (Wed, 10 Feb 2010) $
  */
 
 #ifndef _OpenPhone_VERSION_H
 #define _OpenPhone_VERSION_H
 
+#include <opal/buildopts.h>
+
 #define	PRODUCT_NAME_TEXT	"Open Phone"
 #define	EXE_NAME_TEXT	        "openphone"
 #define	MANUFACTURER_TEXT	"Vox Lucida"
 #define	COPYRIGHT_HOLDER	"Vox Lucida Pty. Ltd. (Australia)"
 
 
-#define MAJOR_VERSION 3
-#define MINOR_VERSION 6
+#define MAJOR_VERSION OPAL_MAJOR
+#define MINOR_VERSION OPAL_MINOR
 #define BUILD_TYPE    BetaCode
-#define BUILD_NUMBER 2
+#define BUILD_NUMBER  OPAL_BUILD
 
 
 #endif  // _OpenPhone_VERSION_H
