@@ -21,9 +21,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22951 $
- * $Author: csoutheren $
- * $Date: 2009-06-22 09:17:13 -0500 (Mon, 22 Jun 2009) $
+ * $Revision: 24409 $
+ * $Author: rjongbloed $
+ * $Date: 2010-05-27 18:41:33 -0500 (Thu, 27 May 2010) $
  */
 
 #ifndef _PlayRTP_MAIN_H
@@ -54,26 +54,27 @@ class PlayRTP : public PProcess
     WORD m_srcPort;
     WORD m_dstPort;
     bool m_singleStep;
-    int m_info;
+    int  m_info;
+    bool m_extendedInfo;
+    bool m_noDelay;
+    bool m_writeEventLog;
+
+    PFile     m_payloadFile;
+    PTextFile m_eventLog;
+    PYUVFile  m_yuvFile;
+    PFilePath m_encodedFileName;
+    PString   m_extraText;
+    int       m_extraHeight;
 
     OpalTranscoder     * m_transcoder;
     PSoundChannel      * m_player;
     PVideoOutputDevice * m_display;
 
-    unsigned m_frameCount;
-    bool m_extendedInfo;
-    bool m_vfu;
-    bool m_videoError;
-    PFilePath m_yuvFileName;
-    PFilePath m_finalVideoFn;
-    PYUVFile m_yuvFile;
-    bool m_noDelay;
-    bool m_writeYUV;
-    bool m_writeNonYUV;
-    bool m_writeEventLog;
-    PTextFile m_eventLog;
-    PString m_extraText;
-    int m_extraHeight;
+    unsigned m_packetCount;
+
+    bool     m_vfu;
+    bool     m_videoError;
+    unsigned m_videoFrames;
 };
 
 
