@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22351 $
- * $Author: csoutheren $
- * $Date: 2009-03-31 07:10:48 +0000 (Tue, 31 Mar 2009) $
+ * $Revision: 24101 $
+ * $Author: rjongbloed $
+ * $Date: 2010-03-04 04:36:04 -0600 (Thu, 04 Mar 2010) $
  */
 
 #include <ptlib.h>
@@ -97,13 +97,12 @@ OpalVideoTranscoder::OpalVideoTranscoder(const OpalMediaFormat & inputMediaForma
   , inDataSize(10*1024)
   , outDataSize(10*1024)
   , videoEncoderMaxOutputSize(10*1024)
-  , forceIFrame(true)
+  , forceIFrame(false)
   , lastFrameWasIFrame(false)
-#if OPAL_STATISTICS
   , m_totalFrames(0)
   , m_keyFrames(0)
-#endif
 {
+  acceptEmptyPayload = true;
 }
 
 
@@ -148,6 +147,7 @@ PINDEX OpalVideoTranscoder::GetOptimalDataFrameSize(PBoolean input) const
 PBoolean OpalVideoTranscoder::ExecuteCommand(const OpalMediaCommand & command)
 {
   if (PIsDescendant(&command, OpalVideoUpdatePicture)) {
+    PTRACE_IF(3, !forceIFrame, "Media\tI-frame forced in video stream");
     forceIFrame = true; // Reset when I-Frame is sent
     return PTrue;
   }
@@ -179,6 +179,11 @@ PString OpalVideoUpdatePicture::GetName() const
   return "Update Picture";
 }
 
+PString OpalVideoUpdatePicture2::GetName() const
+{
+  return "Update Picture 2";
+}
+
 PString OpalTemporalSpatialTradeOff::GetName() const
 {
   return "Temporal Spatial Trade Off";
