@@ -18,9 +18,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21862 $
- * $Author: csoutheren $
- * $Date: 2008-12-23 03:24:53 +0000 (Tue, 23 Dec 2008) $
+ * $Revision: 23831 $
+ * $Author: rjongbloed $
+ * $Date: 2009-12-03 04:21:07 -0600 (Thu, 03 Dec 2009) $
  */
 
 /*
@@ -52,7 +52,7 @@
 OPAL_INSTANTIATE_MEDIATYPE(h224, OpalH224MediaType);
 
 OpalH224MediaType::OpalH224MediaType()
-  : OpalRTPAVPMediaType("h224", "application", 4)
+  : OpalRTPAVPMediaType("h224", "application")
 {
 }
 
@@ -78,7 +78,7 @@ SDPMediaDescription * OpalH224MediaType::CreateSDPMediaDescription(const OpalTra
 }
 
 SDPH224MediaDescription::SDPH224MediaDescription(const OpalTransportAddress & address)
-: SDPRTPAVPMediaDescription(address)
+  : SDPRTPAVPMediaDescription(address, OpalH224MediaType::MediaType())
 {
 }
 
@@ -96,13 +96,13 @@ const OpalMediaFormat & GetOpalH224_H323AnnexQ()
   static class H224_AnnexQ_MediaFormat : public OpalH224MediaFormat { 
     public: 
       H224_AnnexQ_MediaFormat() 
-        : OpalH224MediaFormat("H.224/H323AnnexQ", (RTP_DataFrame::PayloadTypes)100)  // Most other implementations seem to use this payload code
+        : OpalH224MediaFormat("H.224/H323AnnexQ", RTP_DataFrame::DynamicBase)
       { 
         OpalMediaOption * option = new OpalMediaOptionBoolean("HDLC Tunneling", true, OpalMediaOption::MinMerge, false);
         AddOption(option);
       } 
-  } const f; 
-  return f; 
+  } const h224q; 
+  return h224q; 
 };
 
 const OpalMediaFormat & GetOpalH224_HDLCTunneling()
@@ -115,8 +115,8 @@ const OpalMediaFormat & GetOpalH224_HDLCTunneling()
         OpalMediaOption * option = new OpalMediaOptionBoolean("HDLC Tunneling", true, OpalMediaOption::MinMerge, true);
         AddOption(option);
       } 
-  } const f; 
-  return f; 
+  } const h224h; 
+  return h224h; 
 }
 
 OpalH224MediaFormat::OpalH224MediaFormat(
@@ -1137,11 +1137,13 @@ OpalH224MediaStream::OpalH224MediaStream(OpalConnection & connection,
 
 OpalH224MediaStream::~OpalH224MediaStream()
 {
+  Close();
 }
 
-void OpalH224MediaStream::OnPatchStart()
+void OpalH224MediaStream::OnStartMediaPatch()
 {	
   h224Handler.StartTransmit();
+  OpalMediaStream::OnStartMediaPatch();
 }
 
 PBoolean OpalH224MediaStream::Close()
