@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22067 $
+ * $Revision: 23771 $
  * $Author: rjongbloed $
- * $Date: 2009-02-15 16:59:06 -0600 (Sun, 15 Feb 2009) $
+ * $Date: 2009-11-16 19:24:47 -0600 (Mon, 16 Nov 2009) $
  */
 
 #include <ptlib.h>
@@ -53,17 +53,6 @@
 
 #define new PNEW
 
-static class PAuthInitialiseInstantiateMe
-{
-  public:
-    PAuthInitialiseInstantiateMe()
-    {
-      PWLibStupidLinkerHacks::h235AuthLoader = 1;
-#if OPAL_PTLIB_SSL
-      PWLibStupidLinkerHacks::h235AuthProcedure1Loader = 1;
-#endif
-    }
-} instance;
 
 static PTimeInterval AdjustTimeout(unsigned seconds)
 {
@@ -271,14 +260,16 @@ PBoolean H323Gatekeeper::WriteTo(H323TransactionPDU & pdu,
 {
   PWaitAndSignal mutex(transport->GetWriteMutex());
 
-  if (!discoveryComplete && pdu.GetPDU().GetTag() == H225_RasMessage::e_gatekeeperRequest) {
-    if (!transport->WriteConnect(WriteGRQ, &pdu.GetPDU())) {
-      PTRACE(1, "RAS\tError writing discovery PDU: " << transport->GetErrorText());
-      return PFalse;
-    }
-    return PTrue;
-  }
-  return H323Transactor::WriteTo(pdu, addresses, callback);
+  if (discoveryComplete || pdu.GetPDU().GetTag() != H225_RasMessage::e_gatekeeperRequest)
+    return H323Transactor::WriteTo(pdu, addresses, callback);
+
+  PString oldInterface = transport->GetInterface();
+  bool ok = transport->WriteConnect(WriteGRQ, &pdu.GetPDU());
+  transport->SetInterface(oldInterface);
+
+  PTRACE_IF(1, !ok, "RAS\tError writing discovery PDU: " << transport->GetErrorText());
+
+  return ok;
 }
 
 
