@@ -24,9 +24,9 @@
  *
  * The author of this code is Derek J Smithies
  *
- * $Revision: 21421 $
+ * $Revision: 22710 $
  * $Author: dereksmithies $
- * $Date: 2008-10-30 00:36:33 +0000 (Thu, 30 Oct 2008) $
+ * $Date: 2009-05-24 22:17:57 -0500 (Sun, 24 May 2009) $
  */
 
 #include <ptlib.h>
@@ -468,7 +468,8 @@ PBoolean IAX2MiniFrame::ProcessNetworkPacket()
   Read2Bytes(dataWord);
   timeStamp = dataWord;
 
-  PTRACE(5, "Mini frame, header processed.  frame is audio" << PString(isAudio ? " PTrue " : " PFalse " ));
+  PTRACE(5, "Mini frame, header processed. frame is " 
+	 << PString(isAudio ? " audio" : "video"));
   return PTrue;
 }
 
