@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23028 $
+ * $Revision: 24212 $
  * $Author: rjongbloed $
- * $Date: 2009-07-02 10:39:41 +0000 (Thu, 02 Jul 2009) $
+ * $Date: 2010-04-07 22:03:34 -0500 (Wed, 07 Apr 2010) $
  */
 
 #include <ptlib.h>
@@ -82,11 +82,11 @@ OpalLineEndPoint::~OpalLineEndPoint()
 }
 
 
-PBoolean OpalLineEndPoint::MakeConnection(OpalCall & call,
-                                     const PString & remoteParty,
-                                     void * userData,
-                                     unsigned int /*options*/,
-                                     OpalConnection::StringOptions *)
+PSafePtr<OpalConnection> OpalLineEndPoint::MakeConnection(OpalCall & call,
+                                                     const PString & remoteParty,
+                                                              void * userData,
+                                                        unsigned int /*options*/,
+                                     OpalConnection::StringOptions * /*stringOptions*/)
 {
   PTRACE(3, "LID EP\tMakeConnection to " << remoteParty);  
 
@@ -120,7 +120,7 @@ PBoolean OpalLineEndPoint::MakeConnection(OpalCall & call,
   }  
   if (line == NULL){
     PTRACE(1,"LID EP\tMakeConnection cannot find the default line " << defaultLine);
-    return false;
+    return NULL;
 
   }
 
@@ -130,10 +130,7 @@ PBoolean OpalLineEndPoint::MakeConnection(OpalCall & call,
 
 OpalMediaFormatList OpalLineEndPoint::GetMediaFormats() const
 {
-  OpalMediaFormatList mediaFormats;
-#if OPAL_VIDEO
-  AddVideoMediaFormats(mediaFormats);
-#endif
+  OpalMediaFormatList mediaFormats = manager.GetCommonMediaFormats(false, false);
 
   PWaitAndSignal mutex(linesMutex);
 
@@ -359,7 +356,7 @@ OpalLine * OpalLineEndPoint::GetLine(const PString & lineName, bool enableAudio,
     PString lineToken = line->GetToken();
     if (lineName != defaultLine && lineToken != lineName)
       PTRACE(4, "LID EP\tNo match to line name=\"" << lineToken << "\", default=" << defaultLine);
-    else if (line->IsTerminal() == terminating)
+    else if (line->IsTerminal() != terminating)
       PTRACE(4, "LID EP\tNo match to line name=\"" << lineToken << "\", terminating=" << line->IsTerminal());
     else if (!line->IsPresent())
       PTRACE(4, "LID EP\tNo match to line name=\"" << lineToken << "\", not present");
@@ -458,9 +455,13 @@ OpalLineConnection::OpalLineConnection(OpalCall & call,
                                        OpalLineEndPoint & ep,
                                        OpalLine & ln,
                                        const PString & number)
-  : OpalConnection(call, ep, ln.GetToken()),
-    endpoint(ep),
-    line(ln)
+  : OpalConnection(call, ep, ln.GetToken())
+  , endpoint(ep)
+  , line(ln)
+  , wasOffHook(false)
+  , minimumRingCount(2)
+  , m_promptTone(OpalLineInterfaceDevice::DialTone)
+  , handlerThread(NULL)
 {
   localPartyName = ln.GetToken();
   remotePartyNumber = number.Right(number.FindSpan("0123456789*#,"));
@@ -473,11 +474,6 @@ OpalLineConnection::OpalLineConnection(OpalCall & call,
 
   silenceDetector = new OpalLineSilenceDetector(line, (endpoint.GetManager().GetSilenceDetectParams()));
 
-  minimumRingCount = 2;
-
-  wasOffHook = false;
-  handlerThread = NULL;
-
   PTRACE(3, "LID Con\tConnection " << callToken << " created to " << (number.IsEmpty() ? "local" : number));
   
 }
@@ -554,31 +550,28 @@ PBoolean OpalLineConnection::SetConnected()
 
   if (line.IsTerminal()) {
     if (!line.SetConnected()) {
-      PTRACE(1, "LID Con\tCould set line to connected mode on " << *this);
+      PTRACE(1, "LID Con\tCould not set line to connected mode on " << *this);
       return false;
     }
   }
   else {
     if (!line.SetOffHook()) {
-      PTRACE(1, "LID Con\tCould set line off hook on " << *this);
+      PTRACE(1, "LID Con\tCould not set line off hook on " << *this);
       return false;
     }
     PTRACE(4, "LID Con\tAnswered call - gone off hook.");
     wasOffHook = true;
   }
 
-  if (GetMediaStream(OpalMediaType::Audio(), true) == NULL)
-    ownerCall.OpenSourceMediaStreams(*this, OpalMediaType::Audio());
+  AutoStartMediaStreams();
   return OpalConnection::SetConnected();
 }
 
 
 OpalMediaFormatList OpalLineConnection::GetMediaFormats() const
 {
-  OpalMediaFormatList formats = line.GetDevice().GetMediaFormats();
-#if OPAL_VIDEO
-  AddVideoMediaFormats(formats);
-#endif
+  OpalMediaFormatList formats = endpoint.GetManager().GetCommonMediaFormats(false, false);
+  formats += line.GetDevice().GetMediaFormats();
   return formats;
 }
 
@@ -653,7 +646,7 @@ PBoolean OpalLineConnection::PromptUserInput(PBoolean play)
   PTRACE(3, "LID Con\tConnection " << callToken << " dial tone " << (play ? "started" : "stopped"));
 
   if (play) {
-    if (line.PlayTone(OpalLineInterfaceDevice::DialTone)) {
+    if (line.PlayTone(m_promptTone)) {
       PTRACE(3, "LID Con\tPlaying dial tone");
       return true;
     }
@@ -695,9 +688,8 @@ void OpalLineConnection::Monitor()
         StartIncoming(); // We are A-party
       else {
         // If we are in alerting state then we are B-Party
+        AutoStartMediaStreams();
         OnConnectedInternal();
-        if (GetMediaStream(OpalMediaType::Audio(), true) == NULL)
-          ownerCall.OpenSourceMediaStreams(*this, OpalMediaType::Audio());
       }
     }
   }
@@ -831,9 +823,8 @@ PBoolean OpalLineConnection::SetUpConnection()
     }
 
     PTRACE(3, "LID Con\tNo remote party indicated, going off hook without dialing.");
+    AutoStartMediaStreams();
     OnConnectedInternal();
-    if (GetMediaStream(OpalMediaType::Audio(), true) == NULL)
-      ownerCall.OpenSourceMediaStreams(*this, OpalMediaType::Audio());
     return true;
   }
 
@@ -858,8 +849,7 @@ PBoolean OpalLineConnection::SetUpConnection()
 
   PTRACE(3, "LID Con\tGot ring back on " << line);
   // Start media before the OnAlerting to get progress tones (e.g. SIP 183 response)
-  if (GetMediaStream(OpalMediaType::Audio(), true) == NULL)
-    ownerCall.OpenSourceMediaStreams(*this, OpalMediaType::Audio());
+  AutoStartMediaStreams();
   SetPhase(AlertingPhase);
   OnAlerting();
 
@@ -921,6 +911,11 @@ OpalLineMediaStream::OpalLineMediaStream(OpalLineConnection & conn,
   lastSID[0] = 2;
 }
 
+OpalLineMediaStream::~OpalLineMediaStream()
+{
+  Close();
+}
+
 
 PBoolean OpalLineMediaStream::Open()
 {
@@ -936,7 +931,7 @@ PBoolean OpalLineMediaStream::Open()
       return false;
   }
 
-  SetDataSize(GetDataSize(), GetDataSize());
+  SetDataSize(GetDataSize(), GetDataSize()/2);
   PTRACE(3, "LineMedia\tStream opened for " << mediaFormat << ", using "
          << (notUsingRTP ? (useDeblocking ? "reblocked audio" : "audio frames") : "direct RTP"));
 
@@ -1105,13 +1100,13 @@ PBoolean OpalLineMediaStream::WriteData(const BYTE * buffer, PINDEX length, PIND
 }
 
 
-PBoolean OpalLineMediaStream::SetDataSize(PINDEX /*dataSize*/, PINDEX frameSize)
+PBoolean OpalLineMediaStream::SetDataSize(PINDEX dataSize, PINDEX frameTime)
 {
   if (notUsingRTP) {
     if (IsSource())
-      useDeblocking = !line.SetReadFrameSize(frameSize) || line.GetReadFrameSize() != frameSize;
+      useDeblocking = !line.SetReadFrameSize(dataSize) || line.GetReadFrameSize() != dataSize;
     else
-      useDeblocking = !line.SetWriteFrameSize(frameSize) || line.GetWriteFrameSize() != frameSize;
+      useDeblocking = !line.SetWriteFrameSize(dataSize) || line.GetWriteFrameSize() != dataSize;
 
     PTRACE(3, "LineMedia\tStream frame size: rd="
            << line.GetReadFrameSize() << " wr="
@@ -1120,7 +1115,7 @@ PBoolean OpalLineMediaStream::SetDataSize(PINDEX /*dataSize*/, PINDEX frameSize)
   }
 
   // Yes we set BOTH to frameSize, and ignore the dataSize parameter
-  return OpalMediaStream::SetDataSize(frameSize, frameSize);
+  return OpalMediaStream::SetDataSize(dataSize, frameTime);
 }
 
 
@@ -1130,23 +1125,23 @@ PBoolean OpalLineMediaStream::IsSynchronous() const
 }
 
 
-PBoolean OpalLineMediaStream::RequiresPatchThread(OpalMediaStream * sinkStream) const
+PBoolean OpalLineMediaStream::RequiresPatchThread(OpalMediaStream * stream) const
 {
-  OpalLineMediaStream * sinkLine = dynamic_cast<OpalLineMediaStream *>(sinkStream);
-  if (sinkLine != NULL && &line.GetDevice() == &sinkLine->line.GetDevice()) {
-    if (line.GetDevice().SetLineToLineDirect(line.GetLineNumber(), sinkLine->line.GetLineNumber(), true)) {
+  OpalLineMediaStream * lineStream = dynamic_cast<OpalLineMediaStream *>(stream);
+  if (lineStream != NULL && &line.GetDevice() == &lineStream->line.GetDevice()) {
+    if (line.GetDevice().SetLineToLineDirect(line.GetLineNumber(), lineStream->line.GetLineNumber(), true)) {
       PTRACE(3, "LineMedia\tDirect line connection between "
-             << line.GetLineNumber() << " and " << sinkLine->line.GetLineNumber()
+             << line.GetLineNumber() << " and " << lineStream->line.GetLineNumber()
              << " on device " << line.GetDevice());
-      const_cast<OpalLineMediaStream *>(this)->directLineNumber = sinkLine->line.GetLineNumber();
-      sinkLine->directLineNumber = line.GetLineNumber();
+      const_cast<OpalLineMediaStream *>(this)->directLineNumber = lineStream->line.GetLineNumber();
+      lineStream->directLineNumber = line.GetLineNumber();
       return false; // Do not start threads
     }
     PTRACE(2, "LineMedia\tCould not do direct line connection between "
-           << line.GetLineNumber() << " and " << sinkLine->line.GetLineNumber()
+           << line.GetLineNumber() << " and " << lineStream->line.GetLineNumber()
            << " on device " << line.GetDevice());
   }
-  return OpalMediaStream::RequiresPatchThread(sinkStream);
+  return OpalMediaStream::RequiresPatchThread(stream);
 }
 
 
