@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24148 $
+ * $Revision: 24547 $
  * $Author: rjongbloed $
- * $Date: 2010-03-23 03:29:03 -0500 (Tue, 23 Mar 2010) $
+ * $Date: 2010-06-30 01:36:31 -0500 (Wed, 30 Jun 2010) $
  */
 
 #include <ptlib.h>
@@ -622,6 +622,14 @@ bool OpalCall::SelectMediaFormats(const OpalMediaType & mediaType,
 }
 
 
+void OpalCall::StartMediaStreams()
+{
+  PSafePtr<OpalConnection> connection;
+  while (EnumerateConnections(connection, PSafeReadWrite))
+    connection->StartMediaStreams();
+}
+
+
 void OpalCall::CloseMediaStreams()
 {
   PSafePtr<OpalConnection> connection;
