@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24547 $
+ * $Revision: 24705 $
  * $Author: rjongbloed $
- * $Date: 2010-06-30 01:36:31 -0500 (Wed, 30 Jun 2010) $
+ * $Date: 2010-09-15 19:08:56 -0500 (Wed, 15 Sep 2010) $
  */
 
 #include <ptlib.h>
@@ -1334,6 +1334,9 @@ static PString MakeURL(const PString & prefix, const PString & partyName)
 
 PString OpalConnection::GetRemotePartyURL() const
 {
+  if (!remotePartyURL.IsEmpty())
+    return remotePartyURL;
+
   return MakeURL(GetPrefixName(), GetRemotePartyAddress());
 }
 
@@ -1349,6 +1352,7 @@ void OpalConnection::CopyPartyNames(const OpalConnection & other)
   remotePartyName     = other.remotePartyName;
   remotePartyNumber   = other.remotePartyNumber;
   remotePartyAddress  = other.remotePartyAddress;
+  remotePartyURL      = other.remotePartyURL;
   m_calledPartyName   = other.m_calledPartyName;
   m_calledPartyNumber = other.m_calledPartyNumber;
   remoteProductInfo   = other.remoteProductInfo;
