@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24132 $
+ * $Revision: 24917 $
  * $Author: rjongbloed $
- * $Date: 2010-03-19 03:49:38 -0500 (Fri, 19 Mar 2010) $
+ * $Date: 2010-12-02 20:26:58 -0600 (Thu, 02 Dec 2010) $
  */
 
 #include <ptlib.h>
@@ -119,6 +119,14 @@ unsigned OpalGetBuildNumber()
 
 
 OpalProductInfo::OpalProductInfo()
+  : t35CountryCode(0)
+  , t35Extension(0)
+  , manufacturerCode(0)
+{
+}
+
+
+OpalProductInfo::OpalProductInfo(bool)
   : vendor(PProcess::Current().GetManufacturer())
   , name(PProcess::Current().GetName())
   , version(PProcess::Current().GetVersion())
@@ -133,9 +141,10 @@ OpalProductInfo::OpalProductInfo()
     name.Delete(pos, 1);
 }
 
+
 OpalProductInfo & OpalProductInfo::Default()
 {
-  static OpalProductInfo instance;
+  static OpalProductInfo instance(true);
   return instance;
 }
 
@@ -143,18 +152,35 @@ OpalProductInfo & OpalProductInfo::Default()
 PCaselessString OpalProductInfo::AsString() const
 {
   PStringStream str;
-  str << name << '\t' << version << '\t';
-  if (t35CountryCode != 0 && manufacturerCode != 0) {
-    str << (unsigned)t35CountryCode;
-    if (t35Extension != 0)
-      str << '.' << (unsigned)t35Extension;
-    str << '/' << manufacturerCode;
-  }
-  str << '\t' << vendor;
+  str << *this;
   return str;
 }
 
 
+ostream & operator<<(ostream & strm, const OpalProductInfo & info)
+{
+  if (info.name.IsEmpty() &&
+      info.version.IsEmpty() &&
+      info.vendor.IsEmpty() &&
+      info.t35CountryCode == 0 &&
+      info.manufacturerCode == 0)
+    return strm;
+
+  strm << info.name << '\t' << info.version << '\t';
+
+  if (info.t35CountryCode != 0 && info.manufacturerCode != 0) {
+    strm << (unsigned)info.t35CountryCode;
+    if (info.t35Extension != 0)
+      strm << '.' << (unsigned)info.t35Extension;
+    strm << '/' << info.manufacturerCode;
+  }
+
+  strm << '\t' << info.vendor;
+
+  return strm;
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 
 #ifdef _MSC_VER
@@ -162,7 +188,8 @@ PCaselessString OpalProductInfo::AsString() const
 #endif
 
 OpalManager::OpalManager()
-  : defaultUserName(PProcess::Current().GetUserName())
+  : productInfo(OpalProductInfo::Default())
+  , defaultUserName(PProcess::Current().GetUserName())
   , defaultDisplayName(defaultUserName)
   , rtpIpTypeofService(0xb8)  // New DiffServ value for Expidited Forwarding as per RFC3246
   , rtpPayloadSizeMax(576-20-16-12) // Max safe MTU size (576 bytes as per RFC879) minus IP, UDP an RTP headers
