@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23973 $
+ * $Revision: 24687 $
  * $Author: rjongbloed $
- * $Date: 2010-01-24 18:33:51 -0600 (Sun, 24 Jan 2010) $
+ * $Date: 2010-09-12 23:10:00 -0500 (Sun, 12 Sep 2010) $
  */
 
 #include <ptlib.h>
@@ -61,8 +61,8 @@ OpalMediaPatch::OpalMediaPatch(OpalMediaStream & src)
   , m_bypassFromPatch(NULL)
   , patchThread(NULL)
 {
+  PTRACE(5, "Patch\tCreated media patch " << this << ", session " << src.GetSessionID());
   src.SetPatch(this);
-  PTRACE(5, "Patch\tCreated media patch " << this);
 }
 
 
@@ -204,6 +204,7 @@ PBoolean OpalMediaPatch::AddSink(const OpalMediaStreamPtr & sinkStream)
       return false;
     }
     sink->primaryCodec->SetMaxOutputSize(sinkStream->GetDataSize());
+    sink->primaryCodec->SetSessionID(source.GetSessionID());
 
     PTRACE(3, "Patch\tAdded media stream sink " << *sinkStream
            << " using transcoder " << *sink->primaryCodec << ", data size=" << sinkStream->GetDataSize());
@@ -239,6 +240,7 @@ PBoolean OpalMediaPatch::AddSink(const OpalMediaStreamPtr & sinkStream)
     PTRACE(4, "Patch\tCreated two stage codec " << sourceFormat << "/" << intermediateFormat << "/" << destinationFormat << " with ID " << id);
 
     sink->primaryCodec->SetMaxOutputSize(sink->secondaryCodec->GetOptimalDataFrameSize(true));
+    sink->primaryCodec->SetSessionID(source.GetSessionID());
 
     if (!sinkStream->SetDataSize(sink->secondaryCodec->GetOptimalDataFrameSize(false), sourceFormat.GetFrameTime())) {
       PTRACE(1, "Patch\tSink stream " << *sinkStream << " cannot support data size "
@@ -246,6 +248,7 @@ PBoolean OpalMediaPatch::AddSink(const OpalMediaStreamPtr & sinkStream)
       return false;
     }
     sink->secondaryCodec->SetMaxOutputSize(sinkStream->GetDataSize());
+    sink->secondaryCodec->SetSessionID(source.GetSessionID());
 
     PTRACE(3, "Patch\tAdded media stream sink " << *sinkStream
            << " using transcoders " << *sink->primaryCodec
@@ -365,6 +368,8 @@ OpalMediaPatch::Sink::Sink(OpalMediaPatch & p, const OpalMediaStreamPtr & s)
   , primaryCodec(NULL)
   , secondaryCodec(NULL)
   , writeSuccessful(true)
+  , m_lastPayloadType(RTP_DataFrame::IllegalPayloadType)
+  , m_consecutivePayloadTypeMismatches(0)
 #if OPAL_VIDEO
   , rateController(NULL)
 #endif
@@ -477,6 +482,17 @@ void OpalMediaPatch::SetCommandNotifier(const PNotifier & notifier, PBoolean fro
 }
 
 
+void OpalMediaPatch::SetPaused(bool pause)
+{
+  PReadWaitAndSignal mutex(inUse);
+
+  source.SetPaused(pause);
+
+  for (PList<Sink>::iterator s = sinks.begin(); s != sinks.end(); ++s)
+    s->stream->SetPaused(pause);
+}
+
+
 bool OpalMediaPatch::OnStartMediaPatch()
 {
   source.OnStartMediaPatch();
@@ -685,7 +701,7 @@ void OpalMediaPatch::Sink::SetCommandNotifier(const PNotifier & notifier)
 }
 
 
-static bool CannotTranscodeFrame(const OpalTranscoder & codec, RTP_DataFrame & frame)
+bool OpalMediaPatch::Sink::CannotTranscodeFrame(OpalTranscoder & codec, RTP_DataFrame & frame)
 {
   RTP_DataFrame::PayloadTypes pt = frame.GetPayloadType();
 
@@ -699,6 +715,18 @@ static bool CannotTranscodeFrame(const OpalTranscoder & codec, RTP_DataFrame & f
   }
 
   if ((pt != codec.GetPayloadType(true)) && !codec.AcceptOtherPayloads()) {
+    if (pt != m_lastPayloadType) {
+      m_consecutivePayloadTypeMismatches = 0;
+      m_lastPayloadType = pt;
+    }
+    else if (++m_consecutivePayloadTypeMismatches > 10) {
+      PTRACE(2, "Patch\tConsecutive mismatched payload type, was expecting " 
+             << codec.GetPayloadType(true) << ", now using " << pt);
+      OpalMediaFormat fmt = codec.GetInputFormat();
+      fmt.SetPayloadType(pt);
+      codec.UpdateMediaFormats(fmt, OpalMediaFormat());
+      return false;
+    }
     PTRACE(4, "Patch\tRemoving frame with mismatched payload type " << pt << " - should be " << codec.GetPayloadType(true));
     frame.SetPayloadSize(0);   // remove the payload because the transcoder has indicated it won't understand it
     frame.SetPayloadType(codec.GetPayloadType(true)); // Reset pt so if get silence frames from jitter buffer, they don't cause errors
