@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24365 $
+ * $Revision: 24800 $
  * $Author: rjongbloed $
- * $Date: 2010-05-21 01:02:25 -0500 (Fri, 21 May 2010) $
+ * $Date: 2010-10-18 01:30:31 -0500 (Mon, 18 Oct 2010) $
  */
 
 #include <ptlib.h>
@@ -279,18 +279,15 @@ PBoolean OpalRTPConnection::IsRTPNATEnabled(const PIPSocket::Address & localAddr
 }
 
 #if OPAL_VIDEO
-void OpalRTPConnection::OnMediaCommand(OpalMediaCommand & command, INT /*extra*/)
+void OpalRTPConnection::OnMediaCommand(OpalMediaCommand & command, INT sessionID)
 {
   if (PIsDescendant(&command, OpalVideoUpdatePicture)) {
-    OpalMediaStreamPtr videoStream = GetMediaStream(OpalMediaType::Video(), false);
-    if (videoStream != NULL) {
-      RTP_Session * session = m_rtpSessions.GetSession(videoStream->GetSessionID());
-      if (session != NULL) {
-        session->SendIntraFrameRequest();
+    RTP_Session * session = m_rtpSessions.GetSession(sessionID);
+    if (session != NULL) {
+      session->SendIntraFrameRequest();
 #if OPAL_STATISTICS
-        m_VideoUpdateRequestsSent++;
+      m_VideoUpdateRequestsSent++;
 #endif
-      }
     }
   }
 }
@@ -442,7 +439,7 @@ void OpalRTPConnection::SessionFailing(RTP_Session & session)
   // if so, clear the call
   if (m_rtpSessions.AllSessionsFailing()) {
     PTRACE(2, "RTPCon\tClearing call as all RTP session are failing");
-    ClearCall();
+    Release();
   }
 }
 
