@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24339 $
+ * $Revision: 24804 $
  * $Author: rjongbloed $
- * $Date: 2010-05-12 15:46:09 -0500 (Wed, 12 May 2010) $
+ * $Date: 2010-10-18 02:06:57 -0500 (Mon, 18 Oct 2010) $
  */
 
 #include <ptlib.h>
@@ -2186,19 +2186,22 @@ bool RTP_UDP::WriteDataOrControlPDU(const BYTE * framePtr, PINDEX frameSize, boo
 }
 
 
-void RTP_Session::SendIntraFrameRequest(){
-    // Create packet
-    RTP_ControlFrame request;
-    request.StartNewPacket();
-    request.SetPayloadType(RTP_ControlFrame::e_IntraFrameRequest);
-    request.SetPayloadSize(4);
-    // Insert SSRC
-    request.SetCount(1);
-    BYTE * payload = request.GetPayloadPtr();
-    *(PUInt32b *)payload = syncSourceOut;
-    // Send it
-    request.EndPacket();
-    WriteControl(request);
+void RTP_Session::SendIntraFrameRequest()
+{
+  PTRACE(3, "RTP_UDP\tSession " << sessionID << ", Sending Intra-Frame Request via RFC2032");
+
+  // Create packet
+  RTP_ControlFrame request;
+  request.StartNewPacket();
+  request.SetPayloadType(RTP_ControlFrame::e_IntraFrameRequest);
+  request.SetPayloadSize(4);
+  // Insert SSRC
+  request.SetCount(1);
+  BYTE * payload = request.GetPayloadPtr();
+  *(PUInt32b *)payload = syncSourceIn;
+  // Send it
+  request.EndPacket();
+  WriteControl(request);
 }
 
 
