@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24440 $
+ * $Revision: 24924 $
  * $Author: rjongbloed $
- * $Date: 2010-06-02 00:57:45 -0500 (Wed, 02 Jun 2010) $
+ * $Date: 2010-12-05 17:52:45 -0600 (Sun, 05 Dec 2010) $
  */
 
 #include <ptlib.h>
@@ -1554,6 +1554,37 @@ OpalMediaFormatList SDPSessionDescription::GetMediaFormats() const
 }
 
 
+static void SanitiseName(PString & str)
+{
+  PINDEX i = 0;
+  while (i < str.GetLength()) {
+    if (isprint(str[i]))
+      ++i;
+    else
+      str.Delete(i, 1);
+  }
+}
+
+
+void SDPSessionDescription::SetSessionName(const PString & v)
+{
+  sessionName = v;
+  SanitiseName(sessionName);
+  if (sessionName.IsEmpty())
+    sessionName = '-';
+}
+
+
+void SDPSessionDescription::SetUserName(const PString & v)
+{
+  ownerUsername = v;
+  SanitiseName(ownerUsername);
+  ownerUsername.Replace(' ', '_', true);
+  if (ownerUsername.IsEmpty())
+    ownerUsername = '-';
+}
+
+
 #endif // OPAL_SIP
 
 // End of file ////////////////////////////////////////////////////////////////
