@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24442 $
+ * $Revision: 24940 $
  * $Author: rjongbloed $
- * $Date: 2010-06-02 03:17:31 -0500 (Wed, 02 Jun 2010) $
+ * $Date: 2010-12-15 18:50:14 -0600 (Wed, 15 Dec 2010) $
  */
 
 #include <ptlib.h>
@@ -489,9 +489,12 @@ bool SIPEndPoint::ClearDialogContext(SIPDialogContext & context)
   /* This is an extra increment of the sequence number to allow for
      any PDU's in the dialog being sent between the last saved
      context. Highly unlikely this will ever by a million ... */
-  context.GetNextCSeq(1000000);
+  context.IncrementCSeq(1000000);
 
   std::auto_ptr<OpalTransport> transport(CreateTransport(context.GetRemoteURI(), context.GetLocalURI().GetHostName()));
+  if (transport.get() == NULL)
+    return true; // Can't create transport, so remote host uncontactable, assume dialog cleared.
+
   PSafePtr<SIPTransaction> byeTransaction = new SIPTransaction(SIP_PDU::Method_BYE, *this, *transport);
   byeTransaction->InitialiseHeaders(context);
   byeTransaction->WaitForTermination();
