@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 24532 $
+ * $Revision: 24773 $
  * $Author: rjongbloed $
- * $Date: 2010-06-22 20:28:02 -0500 (Tue, 22 Jun 2010) $
+ * $Date: 2010-10-05 20:13:35 -0500 (Tue, 05 Oct 2010) $
  */
 
 #include <ptlib.h>
@@ -39,6 +39,7 @@
 
 #include <sip/sippdu.h>
 
+#include <codec/opalplugin.h>
 #include <sip/sipep.h>
 #include <sip/sipcon.h>
 #include <opal/call.h>
@@ -1702,7 +1703,7 @@ void SIP_PDU::InitialiseHeaders(SIPDialogContext & dialog, const PString & via)
                     dialog.GetRemoteURI(),
                     dialog.GetLocalURI(),
                     dialog.GetCallID(),
-                    dialog.GetNextCSeq(dialog.IsEstablished() && m_method != Method_ACK ? 1 : 0),
+                    dialog.GetNextCSeq(),
                     via);
   SetRoute(dialog.GetRouteSet());
   m_usePeerTransportAddress = dialog.UsePeerTransportAddress();
@@ -1956,9 +1957,9 @@ PBoolean SIP_PDU::Read(OpalTransport & transport)
 
   // get the message from transport/datagram into cmd and parse MIME
   PString cmd;
-  *stream >> cmd;
+  *stream >> cmd >> m_mime;
 
-  if (!stream->good() || cmd.IsEmpty()) {
+  if (!stream->good() || cmd.IsEmpty() || m_mime.IsEmpty()) {
     if (stream == &datagram) {
       transport.setstate(ios::failbit);
       PTRACE(1, "SIP\tInvalid datagram from " << transport.GetLastReceivedAddress()
@@ -2010,14 +2011,6 @@ PBoolean SIP_PDU::Read(OpalTransport & transport)
     return PFalse;
   }
 
-  // Getthe MIME fields
-  *stream >> m_mime;
-  if (!stream->good() || m_mime.IsEmpty()) {
-    PTRACE(2, "SIP\tInvalid MIME received on " << transport);
-    transport.clear(); // Clear flags so BadRequest response is sent by caller
-    return PFalse;
-  }
-
 
   // get the SDP content body
   // if a content length is specified, read that length
@@ -2229,9 +2222,10 @@ void SIP_PDU::SetSDP(SDPSessionDescription * sdp)
 
 SIPDialogContext::SIPDialogContext()
   : m_callId(SIPTransaction::GenerateCallID())
-  , m_lastSentCSeq(1)
+  , m_lastSentCSeq(0)
   , m_lastReceivedCSeq(0)
   , m_usePeerTransportAddress(false)
+  , m_forking(false)
 {
 }
 
@@ -2400,6 +2394,15 @@ void SIPDialogContext::Update(const SIP_PDU & pdu)
 }
 
 
+unsigned SIPDialogContext::GetNextCSeq()
+{
+  if (m_forking && m_lastSentCSeq > 0)
+    return m_lastSentCSeq;
+
+  return ++m_lastSentCSeq;
+}
+
+
 bool SIPDialogContext::IsDuplicateCSeq(unsigned requestCSeq)
 {
   /* See if have had a mesage before and this one is older than the last,
