@@ -23,13 +23,30 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19279 $
+ * $Revision: 23895 $
  * $Author: rjongbloed $
- * $Date: 2008-01-17 04:08:34 +0000 (Thu, 17 Jan 2008) $
+ * $Date: 2009-12-23 00:09:09 -0600 (Wed, 23 Dec 2009) $
  */
 
 #include <ptlib.h>
 
+// Include header files for everything that uses factories or plugins
+#include <h323/h235auth.h>
+#include <rtp/rtp.h>
+#include <rtp/srtp.h>
+#include <codec/opalwavfile.h>
+#include <codec/ratectl.h>
+#include <codec/opalpluginmgr.h>
+#include <lids/lidpluginmgr.h>
+#include <opal/recording.h>
+
+
+#if OPAL_RUBY
+extern "C" void Init_opal();
+static void (*dummy)() = Init_opal;
+#endif
+
+
 ///////////////////////////////////////////////////////////////////////////////
 
 
